"""
Type annotations for botocore.docs module.

Copyright 2025 Vlad Emelianov
"""

from botocore.session import Session

DEPRECATED_SERVICE_NAMES: set[str] = ...

def generate_docs(root_dir: str, session: Session) -> None: ...



"""
Type annotations for botocore.monitoring module.

Copyright 2025 Vlad Emelianov
"""

import socket
from logging import Logger
from typing import Any, Callable, Sequence

from botocore.compat import ensure_bytes as ensure_bytes
from botocore.compat import ensure_unicode as ensure_unicode
from botocore.compat import urlparse as urlparse
from botocore.hooks import BaseEventHooks
from botocore.model import OperationModel

logger: Logger = ...

class Monitor:
    def __init__(self, adapter: MonitorEventAdapter, publisher: SocketPublisher) -> None: ...
    def register(self, event_emitter: BaseEventHooks) -> None: ...
    def capture(self, event_name: str, **payload: Any) -> None: ...

class MonitorEventAdapter:
    def __init__(self, time: Callable[[], float] = ...) -> None: ...
    def feed(
        self, emitter_event_name: str, emitter_payload: dict[str, Any]
    ) -> BaseMonitorEvent: ...

class BaseMonitorEvent:
    def __init__(self, service: str, operation: str, timestamp: int) -> None:
        self.service: str = ...
        self.operation: str = ...
        self.timestamp: int = ...

    def __eq__(self, other: object) -> bool: ...

class APICallEvent(BaseMonitorEvent):
    def __init__(
        self,
        service: str,
        operation: OperationModel,
        timestamp: int,
        latency: int | None = ...,
        attempts: Sequence[APICallAttemptEvent] | None = ...,
        retries_exceeded: bool = ...,
    ) -> None:
        self.latency: int = ...
        self.attempts: Sequence[APICallAttemptEvent] = ...
        self.retries_exceeded: bool = ...

    def new_api_call_attempt(self, timestamp: int) -> APICallAttemptEvent: ...

class APICallAttemptEvent(BaseMonitorEvent):
    def __init__(
        self,
        service: str,
        operation: OperationModel,
        timestamp: int,
        latency: int | None = ...,
        url: str | None = ...,
        http_status_code: int | None = ...,
        request_headers: dict[str, Any] | None = ...,
        response_headers: dict[str, Any] | None = ...,
        parsed_error: dict[str, Any] | None = ...,
        wire_exception: Exception | None = ...,
    ) -> None:
        self.latency: int | None = ...
        self.url: str | None = ...
        self.http_status_code: int | None = ...
        self.request_headers: dict[str, Any] | None = ...
        self.response_headers: dict[str, Any] | None = ...
        self.parsed_error: dict[str, Any] | None = ...
        self.wire_exception: Exception | None = ...

class CSMSerializer:
    def __init__(self, csm_client_id: str) -> None:
        self.csm_client_id: str = ...

    def serialize(self, event: BaseMonitorEvent) -> bytes: ...

class SocketPublisher:
    def __init__(
        self, socket: socket.socket, host: str, port: int, serializer: CSMSerializer
    ) -> None: ...
    def publish(self, event: BaseMonitorEvent) -> None: ...



"""
Type annotations for botocore.endpoint module.

Copyright 2025 Vlad Emelianov
"""

from logging import Logger
from typing import Any, Mapping, Sequence

from botocore.awsrequest import AWSPreparedRequest
from botocore.awsrequest import create_request_object as create_request_object
from botocore.exceptions import HTTPClientError as HTTPClientError
from botocore.history import get_global_history_recorder as get_global_history_recorder
from botocore.hooks import BaseEventHooks
from botocore.hooks import first_non_none_response as first_non_none_response
from botocore.httpsession import URLLib3Session as URLLib3Session
from botocore.model import OperationModel, ServiceModel
from botocore.parsers import ResponseParserFactory
from botocore.response import StreamingBody as StreamingBody
from botocore.utils import get_environ_proxies as get_environ_proxies
from botocore.utils import is_valid_endpoint_url as is_valid_endpoint_url

logger: Logger = ...

history_recorder: Any
DEFAULT_TIMEOUT: int
MAX_POOL_CONNECTIONS: int

def convert_to_response_dict(http_response: Any, operation_model: OperationModel) -> Any: ...

class Endpoint:
    def __init__(
        self,
        host: str,
        endpoint_prefix: str,
        event_emitter: BaseEventHooks,
        response_parser_factory: Any | None = ...,
        http_session: URLLib3Session | None = ...,
    ) -> None:
        self.host: str
        self.http_session: URLLib3Session

    def close(self) -> None: ...
    def make_request(
        self, operation_model: OperationModel, request_dict: Mapping[str, Any]
    ) -> Any: ...
    def create_request(
        self, params: Mapping[str, Any], operation_model: OperationModel | None = ...
    ) -> Any: ...
    def prepare_request(self, request: Any) -> AWSPreparedRequest: ...

class EndpointCreator:
    def __init__(self, event_emitter: BaseEventHooks) -> None: ...
    def create_endpoint(
        self,
        service_model: ServiceModel,
        region_name: str,
        endpoint_url: str,
        verify: bool | None = ...,
        response_parser_factory: ResponseParserFactory | None = ...,
        timeout: float = ...,
        max_pool_connections: int = ...,
        http_session_cls: type[URLLib3Session] = ...,
        proxies: Mapping[str, Any] | None = ...,
        socket_options: Sequence[tuple[int, ...]] | None = ...,
        client_cert: tuple[str, str] | str | None = ...,
        proxies_config: Mapping[str, Any] | None = ...,
    ) -> Any: ...
